@@ -1,7 +1,8 @@
 seqrep.grp <- function(seqdata, group = NULL, diss = NULL, ret = "stat", with.missing = FALSE, mdis, ...) {
 
-  TraMineR:::checkargs(alist(diss = mdis))
-
+  ##TraMineR:::checkargs(alist(diss = mdis))
+  ## TraMineR.check.depr.args is public version of checkargs GR 19.01.2018
+  TraMineR.check.depr.args(alist(diss = mdis))
 	if (!inherits(seqdata,"stslist")){
 		stop("data is NOT a state sequence object, see seqdef function to create one",
             call. = FALSE)
@@ -19,9 +20,23 @@ seqrep.grp <- function(seqdata, group = NULL, diss = NULL, ret = "stat", with.mi
 
     levg <- levels(grp <- factor(grp))
 
-    if (is.null(diss)) diss <- seqdist(seqdata, method="LCS", with.missing=with.missing)
-    diss <- as.matrix(diss)
-    dmax <- max(diss)
+
+		if (is.null(diss)){
+      if (! "method" %in% names(list(...))){
+			  stop("You must provide a distance matrix or a method to compute it", call.=FALSE)
+      } else {
+        oolist <- list(...)
+        oolist[["seqdata"]] <- seqdata
+        oolist[["with.missing"]] <- with.missing
+        dlist <- names(formals(seqdist))
+        diss <- do.call(seqdist, args = oolist[names(oolist) %in% dlist])
+      }
+    }
+		if (inherits(diss, "dist")) {
+      	diss <- as.matrix(diss)
+    }
+
+    dmax <- max(diss) ## same dmax for all groups
 
     q.gr <- gr <- list()
     for (i in 1:length(levg))
